import axios from 'axios';
import ConfigTool from '@/libs/config/ConfigTool';

/**
 * 创建带基础URL的axios实例
 */
const apiClient = axios.create({
  baseURL: ConfigTool.load().backendUrl || '',
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json',
  },
});

// 请求拦截器
apiClient.interceptors.request.use(
  (config) => {
    const cfg = ConfigTool.load();
    if (cfg?.authKey) {
      config.headers['Authorization'] = `Bearer ${cfg.authKey}`;
    }
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);

// 响应拦截器
apiClient.interceptors.response.use(
  (response) => response.data,
  (error) => {
    console.error('API请求错误:', error);
    return Promise.reject(error.response?.data || error.message);
  }
);

/**
 * API模块
 */
export const api = {
  /**
   * 测试API连接
   * @returns {Promise<axios.AxiosResponse<any>>}
   */
  test: () => apiClient.get('/api/test'),

  /**
   * 扫描网络
   * @param subnet 子网地址
   * @returns {Promise<axios.AxiosResponse<any>>}
   */
  scan: (subnet) => apiClient.get(`/api/scan_network`, { params: { subnet } }),

  /**
   * 列出所有设备
   * @returns {Promise<axios.AxiosResponse<any>>}
   */
  listDevices: () => apiClient.get('/api/list_devices'),

  /**
   * 解析命令
   * @param text 文本
   * @returns {Promise<axios.AxiosResponse<any>>}
   */
  parseCommand: (text) => apiClient.post('/api/parse_command', { command: text }),

  /**
   * 应用配置
   * @param switch_ip 交换机ip
   * @param config 配置
   * @returns {Promise<axios.AxiosResponse<any>>}
   */
  applyConfig: (switch_ip, config) => apiClient.post('/api/apply_config', { switch_ip, config }),

  /**
   * 更新基础URL
   * @param url
   */
  updateBaseUrl: (url) => {
    const config = ConfigTool.load();
    config.backendUrl = url;
    ConfigTool.save(config);
    apiClient.defaults.baseURL = url;
  },
};

/**
 * 获取当前配置
 * @returns {{backendUrl: string, authKey: string}}
 */
export const getConfig = () => ConfigTool.load();

/**
 * 获取基础URL
 * @returns {string|string}
 */
export const getBaseUrl = () => ConfigTool.load().backendUrl || '';

export default apiClient;
